@@ -1,12 +1,9 @@
 # OBSS SAHI Tool
 # Code written by Fatih C Akyon, 2020.
 
-import os
-import sys
-
 import numpy as np
 
-from sahi.prediction import ObjectPrediction, PredictionInput
+from sahi.prediction import ObjectPrediction
 from sahi.utils.torch import cuda_is_available, empty_cuda_cache
 
 
@@ -174,7 +171,8 @@ class MmdetDetectionModel(DetectionModel):
         except ImportError:
             raise ImportError(
                 'Please run "pip install -U mmcv mmdet" '
-                'to install MMDetection first for MMDetection inference.')
+                "to install MMDetection first for MMDetection inference."
+            )
 
         from mmdet.apis import init_detector
 
@@ -207,7 +205,8 @@ class MmdetDetectionModel(DetectionModel):
         except ImportError:
             raise ImportError(
                 'Please run "pip install -U mmcv mmdet" '
-                'to install MMDetection first for MMDetection inference.')
+                "to install MMDetection first for MMDetection inference."
+            )
 
         # Confirm model is loaded
         assert (
