@@ -19,7 +19,6 @@ from sahi.utils.cv import (
 )
 from sahi.utils.file import (
     Path,
-    get_base_filename,
     import_class,
     increment_path,
     list_files,
@@ -172,7 +171,7 @@ def get_sliced_prediction(
 
     # create slices from full image
     time_start = time.time()
-    slice_image_result, num_total_invalid_segmentation = slice_image(
+    slice_image_result = slice_image(
         image=image,
         slice_height=slice_height,
         slice_width=slice_width,
