@@ -8,11 +8,11 @@ from collections import Counter, OrderedDict, defaultdict
 from dataclasses import dataclass
 from multiprocessing import Pool
 from pathlib import Path
-from typing import Dict, List
+from typing import Dict, List, Optional
 
 import numpy as np
 from sahi.utils.file import get_base_filename, load_json, save_json
-from sahi.utils.shapely import ShapelyAnnotation, get_shapely_multipolygon
+from sahi.utils.shapely import ShapelyAnnotation, box, get_shapely_multipolygon
 from tqdm import tqdm
 
 
@@ -108,7 +108,9 @@ class CocoAnnotation:
         )
 
     @classmethod
-    def from_coco_annotation_dict(cls, category_name, annotation_dict):
+    def from_coco_annotation_dict(
+        cls, annotation_dict: Dict, category_name: Optional[str] = None
+    ):
         """
         Creates CocoAnnotation object from category name and COCO formatted
         annotation dict (with fields "bbox", "segmentation", "category_id").
@@ -132,6 +134,32 @@ class CocoAnnotation:
                 category_name=category_name,
             )
 
+    @classmethod
+    def from_shapely_annotation(
+        cls,
+        shapely_annotation: ShapelyAnnotation,
+        category_id: int,
+        category_name: str,
+        iscrowd: int,
+    ):
+        """
+        Creates CocoAnnotation object from ShapelyAnnotation object.
+
+        Args:
+            shapely_annotation (ShapelyAnnotation)
+            category_id (int): Category id of the annotation
+            category_name (str): Category name of the annotation
+            iscrowd (int): 0 or 1
+        """
+        coco_annotation = cls(
+            bbox=[0, 0, 0, 0],
+            category_id=category_id,
+            category_name=category_name,
+            iscrowd=iscrowd,
+        )
+        coco_annotation._shapely_annotation = shapely_annotation
+        return coco_annotation
+
     def __init__(
         self,
         segmentation=None,
@@ -161,7 +189,7 @@ class CocoAnnotation:
         assert bbox or segmentation, "you must provide a bbox or polygon"
 
         self._segmentation = segmentation
-        self._bbox = [round(point) for point in bbox] if bbox else bbox
+        bbox = [round(point) for point in bbox] if bbox else bbox
         self._category_id = category_id
         self._category_name = category_name
         self._image_id = image_id
@@ -172,9 +200,23 @@ class CocoAnnotation:
                 segmentation=self._segmentation
             )
         else:
-            shapely_annotation = ShapelyAnnotation.from_coco_bbox(bbox=self._bbox)
+            shapely_annotation = ShapelyAnnotation.from_coco_bbox(bbox=bbox)
         self._shapely_annotation = shapely_annotation
 
+    def get_sliced_coco_annotation(self, slice_bbox: List[int]):
+        shapely_polygon = box(
+            slice_bbox[0], slice_bbox[1], slice_bbox[2], slice_bbox[3]
+        )
+        intersection_shapely_annotation = self._shapely_annotation.get_intersection(
+            shapely_polygon
+        )
+        return CocoAnnotation.from_shapely_annotation(
+            intersection_shapely_annotation,
+            category_id=self.category_id,
+            category_name=self.category_name,
+            iscrowd=self.iscrowd,
+        )
+
     @property
     def area(self):
         """
@@ -251,7 +293,6 @@ class CocoAnnotation:
             "image_id": self.image_id,
             "bbox": self.bbox,
             "category_id": self.category_id,
-            "category_name": self.category_name,
             "segmentation": self.segmentation,
             "iscrowd": self.iscrowd,
             "area": self.area,
@@ -737,7 +778,13 @@ class CocoVideo:
 
 
 class Coco:
-    def __init__(self, name=None, image_dir=None, remapping_dict=None, ignore_negative_samples=True):
+    def __init__(
+        self,
+        name=None,
+        image_dir=None,
+        remapping_dict=None,
+        ignore_negative_samples=False,
+    ):
         """
         Creates Coco object.
 
@@ -822,7 +869,8 @@ class Coco:
         updated_coco = Coco(
             name=self.name,
             image_dir=self.image_dir,
-            remapping_dict=self.remapping_dict
+            remapping_dict=self.remapping_dict,
+            ignore_negative_samples=self.ignore_negative_samples,
         )
         # create category id mapping (currentid2desiredid_mapping)
         for coco_category in copy.deepcopy(self.categories):
@@ -839,9 +887,7 @@ class Coco:
         # add updated categories
         for name in desired_name2id.keys():
             updated_coco_category = CocoCategory(
-                id=desired_name2id[name],
-                name=name,
-                supercategory=name
+                id=desired_name2id[name], name=name, supercategory=name
             )
             updated_coco.add_category(updated_coco_category)
 
@@ -849,9 +895,15 @@ class Coco:
         for coco_image in copy.deepcopy(self.images):
             updated_coco_image = CocoImage.from_coco_image_dict(coco_image.json)
             # update filename to abspath
-            file_name_is_abspath = True if os.path.abspath(coco_image.file_name) == coco_image.file_name else False
+            file_name_is_abspath = (
+                True
+                if os.path.abspath(coco_image.file_name) == coco_image.file_name
+                else False
+            )
             if update_image_filenames and not file_name_is_abspath:
-                updated_coco_image.file_name = str(Path(os.path.abspath(self.image_dir)) / coco_image.file_name)
+                updated_coco_image.file_name = str(
+                    Path(os.path.abspath(self.image_dir)) / coco_image.file_name
+                )
             # update annotations
             for coco_annotation in coco_image.annotations:
                 current_category_id = coco_annotation.category_id
@@ -880,7 +932,9 @@ class Coco:
             verbose: bool
                 If True, merging info is printed
         """
-        assert self.image_dir and coco.image_dir, "image_dir should be provided for merging."
+        assert (
+            self.image_dir and coco.image_dir
+        ), "image_dir should be provided for merging."
 
         if verbose:
             if not desired_name2id:
@@ -903,7 +957,9 @@ class Coco:
 
         # update categories and image paths
         for coco in [coco1, coco2]:
-            coco.update_categories(desired_name2id=desired_name2id, update_image_filenames=True)
+            coco.update_categories(
+                desired_name2id=desired_name2id, update_image_filenames=True
+            )
 
         # combine images and categories
         coco1.images.extend(coco2.images)
@@ -918,7 +974,14 @@ class Coco:
             )
 
     @classmethod
-    def from_coco_dict_or_path(cls, coco_dict_or_path, desired_name2id=None, image_dir=None, remapping_dict=None, mp=False):
+    def from_coco_dict_or_path(
+        cls,
+        coco_dict_or_path,
+        desired_name2id=None,
+        image_dir=None,
+        remapping_dict=None,
+        ignore_negative_samples=False,
+    ):
         """
         Creates coco object from COCO formatted dict or COCO dataset file path.
 
@@ -932,9 +995,8 @@ class Coco:
                 Base file directory that contains dataset images. Required for merging and yolov5 conversion.
             remapping_dict: dict
                 {1:0, 2:1} maps category id 1 to 0 and category id 2 to 1
-            mp: bool
-                If True, multiprocess mode is on.
-                Should be called in 'if __name__ == __main__:' block.
+            ignore_negative_samples: bool
+                If True ignores images without annotations in all operations.
 
         Properties:
             images: list of CocoImage
@@ -943,9 +1005,9 @@ class Coco:
         # init coco object
         coco = cls(image_dir=image_dir, remapping_dict=remapping_dict)
 
-        assert (type(coco_dict_or_path) == str
-            or type(coco_dict_or_path) == dict), \
-            "coco_dict_or_path should be dict or str"
+        assert (
+            type(coco_dict_or_path) == str or type(coco_dict_or_path) == dict
+        ), "coco_dict_or_path should be dict or str"
 
         # load coco dict if path is given
         if type(coco_dict_or_path) == str:
@@ -955,20 +1017,19 @@ class Coco:
 
         # arrange image id to annotation id mapping
         coco.add_categories_from_coco_category_list(coco_dict["categories"])
-        if mp:
-            imageid2annotationlist = get_imageid2annotationlist_mapping_mp(coco_dict)
-        else:
-            imageid2annotationlist = get_imageid2annotationlist_mapping(coco_dict)
+        image_id_to_annotation_list = get_imageid2annotationlist_mapping(coco_dict)
         category_mapping = coco.category_mapping
 
         for coco_image_dict in coco_dict["images"]:
             coco_image = CocoImage.from_coco_image_dict(coco_image_dict)
-            annotation_list = imageid2annotationlist[coco_image_dict["id"]]
+            annotation_list = image_id_to_annotation_list[coco_image_dict["id"]]
             for coco_annotation_dict in annotation_list:
                 # apply category remapping if remapping_dict is provided
                 if coco.remapping_dict is not None:
                     # apply category remapping (id:id)
-                    category_id = coco.remapping_dict[coco_annotation_dict["category_id"]]
+                    category_id = coco.remapping_dict[
+                        coco_annotation_dict["category_id"]
+                    ]
                     # update category id
                     coco_annotation_dict["category_id"] = category_id
                 else:
@@ -1015,13 +1076,22 @@ class Coco:
         """
         Iterates over all annotations and calculates total number of
         """
+        # init all stats
         num_annotations = 0
         num_images = len(self.images)
+        num_negative_images = 0
         num_categories = len(self.json_categories)
-        category_name_to_zero = {category["name"]:0 for category in self.json_categories}
+        category_name_to_zero = {
+            category["name"]: 0 for category in self.json_categories
+        }
+        category_name_to_inf = {
+            category["name"]: float("inf") for category in self.json_categories
+        }
         num_images_per_category = copy.deepcopy(category_name_to_zero)
         num_annotations_per_category = copy.deepcopy(category_name_to_zero)
-        min_num_annotations_in_image = 1e10
+        min_annotation_area_per_category = copy.deepcopy(category_name_to_inf)
+        max_annotation_area_per_category = copy.deepcopy(category_name_to_zero)
+        min_num_annotations_in_image = float("inf")
         max_num_annotations_in_image = 0
         total_annotation_area = 0
         min_annotation_area = 1e10
@@ -1034,10 +1104,27 @@ class Coco:
                 num_annotations_per_category[annotation.category_name] += 1
                 image_contains_category[annotation.category_name] = 1
                 # update min&max annotation area
-                if annotation_area>max_annotation_area:
+                if annotation_area > max_annotation_area:
                     max_annotation_area = annotation_area
-                if annotation_area<min_annotation_area:
+                if annotation_area < min_annotation_area:
                     min_annotation_area = annotation_area
+                if (
+                    annotation_area
+                    > max_annotation_area_per_category[annotation.category_name]
+                ):
+                    max_annotation_area_per_category[
+                        annotation.category_name
+                    ] = annotation_area
+                if (
+                    annotation_area
+                    < min_annotation_area_per_category[annotation.category_name]
+                ):
+                    min_annotation_area_per_category[
+                        annotation.category_name
+                    ] = annotation_area
+            # update num_negative_images
+            if len(image.annotations) == 0:
+                num_negative_images += 1
             # update num_annotations
             num_annotations += len(image.annotations)
             # update num_images_per_category
@@ -1046,17 +1133,20 @@ class Coco:
             )
             # update min&max_num_annotations_in_image
             num_annotations_in_image = len(image.annotations)
-            if num_annotations_in_image>max_num_annotations_in_image:
+            if num_annotations_in_image > max_num_annotations_in_image:
                 max_num_annotations_in_image = num_annotations_in_image
-            if num_annotations_in_image<min_num_annotations_in_image:
+            if num_annotations_in_image < min_num_annotations_in_image:
                 min_num_annotations_in_image = num_annotations_in_image
-        avg_num_annotations_in_image = num_annotations/num_images
-        avg_annotation_area = total_annotation_area/num_annotations
+        avg_num_annotations_in_image = num_annotations / (
+            num_images - num_negative_images
+        )
+        avg_annotation_area = total_annotation_area / num_annotations
 
         self._stats = {
             "num_images": num_images,
             "num_annotations": num_annotations,
             "num_categories": num_categories,
+            "num_negative_images": num_negative_images,
             "num_images_per_category": num_images_per_category,
             "num_annotations_per_category": num_annotations_per_category,
             "min_num_annotations_in_image": min_num_annotations_in_image,
@@ -1064,12 +1154,12 @@ class Coco:
             "avg_num_annotations_in_image": avg_num_annotations_in_image,
             "min_annotation_area": min_annotation_area,
             "max_annotation_area": max_annotation_area,
-            "avg_annotation_area": avg_annotation_area
+            "avg_annotation_area": avg_annotation_area,
+            "min_annotation_area_per_category": min_annotation_area_per_category,
+            "max_annotation_area_per_category": max_annotation_area_per_category,
         }
 
-    def split_coco_as_train_val(
-        self, train_split_rate=0.9, numpy_seed=0
-    ):
+    def split_coco_as_train_val(self, train_split_rate=0.9, numpy_seed=0):
         """
         Split images into train-val and returns them as sahi.utils.coco.Coco objects.
 
@@ -1098,15 +1188,14 @@ class Coco:
 
         # form train val coco objects
         train_coco = Coco(
-            name=self.name if self.name else "split" + '_train',
-            image_dir=self.image_dir
+            name=self.name if self.name else "split" + "_train",
+            image_dir=self.image_dir,
         )
         train_coco.images = train_images
         train_coco.categories = self.categories
 
         val_coco = Coco(
-            name=self.name if self.name else "split" + '_val',
-            image_dir=self.image_dir
+            name=self.name if self.name else "split" + "_val", image_dir=self.image_dir
         )
         val_coco.images = val_images
         val_coco.categories = self.categories
@@ -1117,7 +1206,7 @@ class Coco:
             "val_coco": val_coco,
         }
 
-    def export_as_yolov5(self, output_dir, train_split_rate=1, numpy_seed=0):
+    def export_as_yolov5(self, output_dir, train_split_rate=1, numpy_seed=0, mp=False):
         """
         Exports current COCO dataset in ultralytics/yolov5 format.
         Creates train val folders with image symlinks and txt files and a data yaml file.
@@ -1131,13 +1220,17 @@ class Coco:
                 If in between 0-1, both train/val splits will be calculated and exported.
             numpy_seed: int
                 To fix the numpy seed.
+            mp: bool
+                If True, multiprocess mode is on.
+                Should be called in 'if __name__ == __main__:' block.
         """
         try:
             import yaml
         except ImportError:
             raise ImportError(
                 'Please run "pip install -U pyyaml" '
-                'to install yaml first for yolov5 formatted exporting.')
+                "to install yaml first for yolov5 formatted exporting."
+            )
 
         # set split_mode
         if 0 < train_split_rate and train_split_rate < 1:
@@ -1177,11 +1270,17 @@ class Coco:
         # create image symlinks and annotation txts
         if split_mode in ["TRAINVAL", "TRAIN"]:
             export_yolov5_images_and_txts_from_coco_object(
-                output_dir=train_dir, coco=train_coco
+                output_dir=train_dir,
+                coco=train_coco,
+                ignore_negative_samples=self.ignore_negative_samples,
+                mp=mp,
             )
         if split_mode in ["TRAINVAL", "VAL"]:
             export_yolov5_images_and_txts_from_coco_object(
-                output_dir=val_dir, coco=val_coco
+                output_dir=train_dir,
+                coco=val_coco,
+                ignore_negative_samples=self.ignore_negative_samples,
+                mp=mp,
             )
 
         # create yolov5 data yaml
@@ -1195,7 +1294,7 @@ class Coco:
         with open(yaml_path, "w") as outfile:
             yaml.dump(data, outfile, default_flow_style=None)
 
-    def get_subsampled_coco(self, subsample_ratio=10):
+    def get_subsampled_coco(self, subsample_ratio=2):
         """
         Subsamples images with subsample_ratio and returns as sahi.utils.coco.Coco object.
 
@@ -1208,17 +1307,70 @@ class Coco:
         subsampled_coco = Coco(
             name=self.name,
             image_dir=self.image_dir,
-            remapping_dict=self.remapping_dict
+            remapping_dict=self.remapping_dict,
+            ignore_negative_samples=self.ignore_negative_samples,
         )
         subsampled_coco.add_categories_from_coco_category_list(self.json_categories)
-        for image_ind in tqdm(range(0, len(self.images), subsample_ratio)):
+        for image_ind in range(0, len(self.images), subsample_ratio):
             subsampled_coco.add_image(self.images[image_ind])
 
         return subsampled_coco
 
+    def get_area_filtered_coco(
+        self, min=0, max=float("inf"), intervals_per_category=None
+    ):
+        """
+        Filters annotation areas with given min and max values and returns remaining
+        images as sahi.utils.coco.Coco object.
+
+        Args:
+            min: int
+                minimum allowed area
+            max: int
+                maximum allowed area
+            intervals_per_category: dict of dicts
+                {
+                    "human": {"min": 20, "max": 10000},
+                    "vehicle": {"min": 50, "max": 15000},
+                }
+        Returns:
+            area_filtered_coco: sahi.utils.coco.Coco
+        """
+        area_filtered_coco = Coco(
+            name=self.name,
+            image_dir=self.image_dir,
+            remapping_dict=self.remapping_dict,
+            ignore_negative_samples=self.ignore_negative_samples,
+        )
+        area_filtered_coco.add_categories_from_coco_category_list(self.json_categories)
+        for image in self.images:
+            is_valid_image = True
+            for annotation in image.annotations:
+                if (
+                    intervals_per_category is not None
+                    and annotation.category_name in intervals_per_category.keys()
+                ):
+                    category_based_min = intervals_per_category[
+                        annotation.category_name
+                    ]["min"]
+                    category_based_max = intervals_per_category[
+                        annotation.category_name
+                    ]["max"]
+                    if (
+                        annotation.area < category_based_min
+                        or annotation.area > category_based_max
+                    ):
+                        is_valid_image = False
+                if annotation.area < min or annotation.area > max:
+                    is_valid_image = False
+            if is_valid_image:
+                area_filtered_coco.add_image(image)
+
+        return area_filtered_coco
+
 
 def export_yolov5_images_and_txts_from_coco_object(
-    output_dir, coco
+    output_dir, coco, ignore_negative_samples=False, mp=False
 ):
     """
     Creates image symlinks and annotation txts in yolo format from coco dataset.
@@ -1228,38 +1380,78 @@ def export_yolov5_images_and_txts_from_coco_object(
             Export directory.
         coco: sahi.utils.coco.Coco
             Initialized Coco object that contains images and categories.
+        ignore_negative_samples: bool
+            If True ignores images without annotations in all operations.
+        mp: bool
+            If True, multiprocess mode is on.
+            Should be called in 'if __name__ == __main__:' block.
     """
 
-    for image in tqdm(coco.images):
+    print("generating image symlinks and annotation files for yolov5..."),
+    if mp:
+        with Pool(processes=48) as pool:
+            args = [
+                (coco_image, coco.image_dir, output_dir, ignore_negative_samples)
+                for coco_image in coco.images
+            ]
+            pool.starmap(
+                export_single_yolov5_image_and_corresponding_txt,
+                tqdm(args, total=len(args)),
+            )
+    else:
+        for coco_image in tqdm(coco.images):
+            export_single_yolov5_image_and_corresponding_txt(
+                coco_image, coco.image_dir, output_dir, ignore_negative_samples
+            )
+
+
+def export_single_yolov5_image_and_corresponding_txt(
+    coco_image, coco_image_dir, output_dir, ignore_negative_samples=False
+):
+    """
+    Generates yolov5 formatted image symlink and annotation txt file.
+
+    Args:
+        coco_image: sahi.utils.coco.CocoImage
+        coco_image_dir: str
+        output_dir: str
+            Export directory.
+        ignore_negative_samples: bool
+            If True ignores images without annotations in all operations.
+    """
+    if not ignore_negative_samples or len(coco_image.annotations) > 0:
         # set coco and yolo image paths
-        if Path(image.file_name).is_file():
-            coco_image_path = os.path.abspath(image.file_name)
+        if Path(coco_image.file_name).is_file():
+            coco_image_path = os.path.abspath(coco_image.file_name)
         else:
-            assert coco.image_dir, "You have to specify image_dir " \
-                "of Coco object for yolov5 conversion."
-            coco_image_path = os.path.abspath(str(Path(coco.image_dir) / image.file_name))
-        yolo_image_path_temp = str(Path(output_dir) / ((coco.name if coco.name else "") + "_" + Path(image.file_name).name))
+            assert coco_image_dir is not None, (
+                "You have to specify image_dir " "of Coco object for yolov5 conversion."
+            )
+            coco_image_path = os.path.abspath(
+                str(Path(coco_image_dir) / coco_image.file_name)
+            )
+        yolo_image_path_temp = str(Path(output_dir) / Path(coco_image.file_name).name)
         # increment target file name if already present
         yolo_image_path = copy.deepcopy(yolo_image_path_temp)
         name_increment = 2
         while Path(yolo_image_path).is_file():
             yolo_image_path = yolo_image_path_temp.replace(
-                Path(image.file_name).stem,
-                Path(image.file_name).stem + "_" + str(name_increment)
+                Path(coco_image.file_name).stem,
+                Path(coco_image.file_name).stem + "_" + str(name_increment),
             )
             name_increment += 1
         # create a symbolic link pointing to coco_image_path named yolo_image_path
         os.symlink(coco_image_path, yolo_image_path)
         # calculate annotation normalization ratios
-        width = image.width
-        height = image.height
+        width = coco_image.width
+        height = coco_image.height
         dw = 1.0 / (width)
         dh = 1.0 / (height)
         # set annotation filepath
         image_file_suffix = Path(yolo_image_path).suffix
         yolo_annotation_path = yolo_image_path.replace(image_file_suffix, ".txt")
         # create annotation file
-        annotations = image.annotations
+        annotations = coco_image.annotations
         with open(yolo_annotation_path, "w") as outfile:
             for annotation in annotations:
                 # convert coco bbox to yolo bbox
@@ -1497,30 +1689,9 @@ def merge_from_file(coco_path1: str, coco_path2: str, save_path: str):
     save_json(merged_coco_dict, save_path)
 
 
-def get_image_annotations(image_id, annotations):
-    image_annotations = []
-    for annotation in annotations:
-        if annotation["image_id"] == image_id:
-            image_annotations.append(annotation)
-    return image_id, image_annotations
-
-
-def get_imageid2annotationlist_mapping_mp(coco_dict):
-    """
-    Multiprocess version of sahi.utils.coco.get_imageid2annotationlist_mapping. (3 times faster)
-    """
-    imageid2annotationlist_mapping = {}
-    annotations = coco_dict["annotations"]
-    print("indexing coco dataset annotations...")
-    with Pool(processes=48) as pool:
-        args = [(image["id"], annotations) for image in coco_dict["images"]]
-        imageid_annotationlist_pairs = pool.starmap(get_image_annotations, tqdm(args, total=len(args)))
-    imageid2annotationlist_mapping = dict(imageid_annotationlist_pairs)
-
-    return imageid2annotationlist_mapping
-
-
-def get_imageid2annotationlist_mapping(coco_dict: dict) -> dict:
+def get_imageid2annotationlist_mapping(
+    coco_dict: dict,
+) -> Dict[int, List[CocoAnnotation]]:
     """
     Get image_id to annotationlist mapping for faster indexing.
 
@@ -1530,14 +1701,14 @@ def get_imageid2annotationlist_mapping(coco_dict: dict) -> dict:
             coco dict with fields "images", "annotations", "categories"
     Returns
     -------
-        imageid2annotationlist_mapping : dict
+        image_id_to_annotation_list : dict
         {
-            1: [COCOAnnotation, COCOAnnotation, COCOAnnotation],
-            2: [COCOAnnotation]
+            1: [CocoAnnotation, CocoAnnotation, CocoAnnotation],
+            2: [CocoAnnotation]
         }
 
         where
-        COCOAnnotation = {
+        CocoAnnotation = {
             'area': 2795520,
             'bbox': [491.0, 1035.0, 153.0, 182.0],
             'category_id': 1,
@@ -1547,20 +1718,16 @@ def get_imageid2annotationlist_mapping(coco_dict: dict) -> dict:
             'segmentation': [[491.0, 1035.0, 644.0, 1035.0, 644.0, 1217.0, 491.0, 1217.0]]
         }
     """
-    imageid2annotationlist_mapping = {}
+    image_id_to_annotation_list: Dict = defaultdict(list)
     print("indexing coco dataset annotations...")
-    for image in tqdm(coco_dict["images"]):
-        image_id = image["id"]
-        imageid2annotationlist_mapping[image_id] = []
+    for annotation in tqdm(coco_dict["annotations"]):
+        image_id = annotation["image_id"]
+        image_id_to_annotation_list[image_id].append(annotation)
 
-        for annotation in coco_dict["annotations"]:
-            if annotation["image_id"] == image_id:
-                imageid2annotationlist_mapping[image_id].append(annotation)
-
-    return imageid2annotationlist_mapping
+    return image_id_to_annotation_list
 
 
-def create_coco_dict(images, categories, ignore_negative_samples=True):
+def create_coco_dict(images, categories, ignore_negative_samples=False):
     """
     Creates COCO dict with fields "images", "annotations", "categories".
 
@@ -1694,7 +1861,7 @@ def split_coco_as_train_val(
     train_annotations = list()
     val_annotations = list()
     print("splitting coco dataset into train/val...")
-    for annotation in tqdm(coco_dict["annotations"]):
+    for annotation in coco_dict["annotations"]:
         image_index_for_annotation = image_id_2_idx[annotation["image_id"]]
         if image_index_for_annotation in train_indices:
             train_annotations.append(annotation)
