@@ -5,9 +5,10 @@ import copy
 import os
 import random
 import time
-
+from typing import Union
 import cv2
 import numpy as np
+from PIL import Image
 from sahi.utils.file import create_dir
 
 
@@ -82,7 +83,8 @@ def read_large_image(image_path):
         except ImportError:
             raise ImportError(
                 'Please run "pip install -U scikit-image" '
-                'to install scikit-image first for large image handling.')
+                "to install scikit-image first for large image handling."
+            )
         image0 = skimage.io.imread(image_path, as_grey=False).astype(np.uint8)  # [::-1]
         use_cv2 = False
     return image0, use_cv2
@@ -99,6 +101,28 @@ def read_image(image_path):
     return image
 
 
+def read_image_as_pil(image: Union[Image.Image, str, np.ndarray]):
+    """
+    Loads an image as PIL.Image.Image.
+
+    Args:
+        image : Can be image path (str), opencv image (np.ndarray) or PIL.Image
+    """
+    # read image if str image path is provided
+    if isinstance(image, str):
+        # read in image, cv2 fails on large files
+        image_pil = Image.open(image)
+    elif isinstance(image, np.ndarray):
+        if image.shape[0] < 5:  # image in CHW
+            image = image[:, :, ::-1]
+        image_pil = Image.fromarray(image)
+    elif isinstance(image, Image.Image):
+        image_pil = image
+    else:
+        TypeError("read image with 'pillow' using 'Image.open()'")
+    return image_pil
+
+
 def select_random_color():
     """
     Selects random color.
